#
# spec file for package mint-x-icon-theme
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name   Mint-X
Name:           mint-x-icon-theme
Version:        1.6.5
Release:        1.6
Summary:        Mint-X icon theme
License:        GPL-3.0-or-later
URL:            https://github.com/linuxmint/mint-x-icons
Source:         http://packages.linuxmint.com/pool/main/m/mint-x-icons/mint-x-icons_%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
Requires:       adwaita-icon-theme
Requires:       hicolor-icon-theme
BuildArch:      noarch

%description
A mint/metal theme based on mintified versions of
Clearlooks Revamp, Elementary and Faenza.

%prep
%setup -q -n mint-x-icons
# Remove broken symlinks
# https://github.com/linuxmint/mint-x-icons/issues/194
find . -xtype l -exec rm {} \;

%build
# Nothing to build.

%install
mkdir -p %{buildroot}%{_datadir}/icons/
ls .%{_datadir}/icons/ | while read icons; do
    sed -i 's/^\(Inherits=\).*$/\1Adwaita/' .%{_datadir}/icons/$icons/index.theme
    cp -a .%{_datadir}/icons/$icons %{buildroot}%{_datadir}/icons/$icons
    # %%icon_theme_cache_create_ghost fails to work here.
    touch %{buildroot}%{_datadir}/icons/$icons/icon-theme.cache
done
%fdupes %{buildroot}%{_datadir}/icons/

%if 0%{?suse_version} < 1500
%post
%icon_theme_cache_post %{_name}
%icon_theme_cache_post %{_name}-Aqua
%icon_theme_cache_post %{_name}-Blue
%icon_theme_cache_post %{_name}-Brown
%icon_theme_cache_post %{_name}-Dark
%icon_theme_cache_post %{_name}-Grey
%icon_theme_cache_post %{_name}-Orange
%icon_theme_cache_post %{_name}-Pink
%icon_theme_cache_post %{_name}-Purple
%icon_theme_cache_post %{_name}-Red
%icon_theme_cache_post %{_name}-Sand
%icon_theme_cache_post %{_name}-Teal
%icon_theme_cache_post %{_name}-Yellow

# No need for %%icon_theme_cache_postun in %%postun since themes won't exist anymore.
%endif

%files
%license debian/copyright
%doc debian/changelog
%{_datadir}/icons/%{_name}*
%ghost %{_datadir}/icons/%{_name}*/icon-theme.cache

%changelog
* Sat Nov 25 2023 Dirk Müller <dmueller@suse.com>
- update to 1.6.5:
  * Add PIX icon
  * Remove Mint-X-Dark
  * Add definitions for folder-color-switcher
  * Add thingy icon
  * Add xfsm-lock
  * Add a create-links script
  * Add missing icons and support for Xfce 4.16
  * Add sticky
  * Add missing sizes for folder-recent
  * Add caps and num-lock symbolic indicator icons.
  * Make caps-lock and num-lock symbolic icons cinnamon-specific.
  * Add cs-online-accounts
* Thu Jan 14 2021 andy great <andythe_great@pm.me>
- Update to version 1.5.9.
  * Add cs-online-accounts
* Sat Dec 26 2020 andy great <andythe_great@pm.me>
- Update to version 1.5.8.
  * Add hypnotix
- Updates for version 1.5.7
  * Add webapp icons for popular websites
- Updates for version 1.5.6
  * Make system-file-manager look like folder
* Fri Oct  2 2020 andy great <andythe_great@pm.me>
- Remove group tag.
* Wed Jun 10 2020 andy great <andythe_great@pm.me>
- Remove _service file.
- Update to verion 1.5.5.
  * Add org.gnome.ArchiveManager icon.
* Fri Mar 27 2020 andy great <andythe_great@pm.me>
- Update to version 1.5.3 and add _service file.
* Fri Nov 30 2018 sor.alexei@meowr.ru
- Update to version 1.5.1:
  * Add symbolic icons for some system actions.
  * Fix nemo sidebar bookmark icon.
  * Add wireless-secure icons.
* Tue Jun 26 2018 sor.alexei@meowr.ru
- Update to version 1.5.0:
  * Add start-here-symbolic.
* Wed Jun  6 2018 sor.alexei@meowr.ru
- Update to version 1.4.9 (changes since 1.4.7):
  * Add symbolic icons for places, phone and switch-user.
  * Add icons/links for GOA (GNOME Online Accounts).
* Sat Apr 28 2018 sor.alexei@meowr.ru
- Update to version 1.4.7:
  * volume muted symbolic icon: Change the shade of grey.
  * Add a nemo icon.
  * Add a symbolic link for calibre viewers.
  * Rename microphone-sensitivity-none to
    microphone-sensitivity-muted.
  * Add system-lock-screen-symbolic.
* Tue Nov 21 2017 sor.alexei@meowr.ru
- Update to version 1.4.6:
  * Add the Timeshift icon.
* Sun Nov 12 2017 sor.alexei@meowr.ru
- Update to version 1.4.5:
  * Add the WhatsApp icon.
* Sat Nov  4 2017 sor.alexei@meowr.ru
- Update to version 1.4.4:
  * Status: Fix network icons in 48px and 96px.
  * devices: Add a couple 16px icons for removable drives.
  * Add some additional sizes for cairo-dock.
  * Add the original base faenza icons to src/.
  * Add icon for PIA Manager.
  * Add some symbolic actions.
  * Add GOA icons.
  * Provide GOA icons in all dimensions.
  * Add SVG audio icons for the volume hotkey pop up indicator.
* Mon Jun 12 2017 sor.alexei@meowr.ru
- Update to version 1.4.3:
  * Restyle the 32px network icons.
  * Restyle the 32px volume icons.
  * Restyle the 32px battery status icons.
* Sun May  7 2017 sor.alexei@meowr.ru
- Update to version 1.4.2:
  * Link unity-monodevelop to monodevelop.
  * Link minecraft-launcher to minecraft.
* Wed Mar 22 2017 sor.alexei@meowr.ru
- Update to version 1.4.1:
  * Fix some broken links.
  * Add a link for the new Skype icons.
  * Add Mint-X-Dark/status/22/system-devices-panel.png.
* Tue Nov  8 2016 sor.alexei@meowr.ru
- Update to version 1.4.0:
  * Add a missing symbolic link places/16/folder-videos.svg for
    each extra colour theme.
  * actions: Add some more symbolic icons.
  * Add a size 128px trash icon.
* Tue Sep 27 2016 sor.alexei@meowr.ru
- Update to version 1.3.9:
  * Symlink fix.
* Tue Aug 30 2016 sor.alexei@meowr.ru
- Update to version 1.3.8:
  * Add some symbolics.
  * blueman disabled has become symbolic.
* Tue Jun  7 2016 sor.alexei@meowr.ru
- Update to version 1.3.7:
  * Fix corrupt status/96/image-missing.svg.
- Inherit "Adwaita" icon theme instead of "gnome".
* Thu May 12 2016 sor.alexei@meowr.ru
- Update to version 1.3.6 (changes since 1.3.2):
  * Add actions icons for clementine with HDPI-support, fix
    "search" symlink.
  * Rename 32px and 48px icon "view-media-lyrics" to
    "music-library", "view-media-lyrics" as symlink "music-library".
  * Add icons: birdie, corebird, gitkraken, lollypop, nylas,
    qbittorrent, qpdfview.
  * Add icons & symlinks: gnome-mpv, sublimetext.
  * Fix icons doublecmd, gprename, smartgit, telegram, viber
    (16, 22, 24, 32 px's)
  * Change bleachbit icons (symlinks earlier).
  * Add symlinks for gtk-index & helpfaq (need actions icons for
    Shutter application)
  * Fix form & size firefox icon (16, 22, 14 px's).
  * Add symlinks for Spotify client: spotify-client -> spotify.
  * Add icon-theme.cache files to the .gitignore list.
  * Add keepassx2 app symlinks to keepassx.
  * New Spotify icons.
  * Don't inherit ubuntu-mono-light or gnome-color-wise
  * Add icons for Motorola Moto G 2 phone.
  * Update Moto G 2 icons, add white Moto G 2 icons, and add black
    and white iPhone 6 icons.
  * Improve Moto G 2 icons and add Samsung Galaxy S4 icons in
    White, Black, Red and Blue.
  * Add iPhone 5 icons, black and white.
  * Improve several white iPhone 6 icons
  * Add black and white iPhone 4S icons.
  * Change all files names to use hyphens rather than underscores
    to specify colours.
  * Improve and standardise some colours on a few phones.
* Sun Nov  8 2015 sor.alexei@meowr.ru
- Update to version 1.3.2:
  * UPS icons.
  * Multicolour trash-bin stripe.
  * ODP support.
  * vsd and vsdx icons support.
  * Add SVG-icons doublecmd, smartgit, telegram, viber.
  * Add symlinks geary and plank.
  * Add gprename icon.
  * Update all haguichi icons to use the new logo, add 32/48/96
    status icons.
  * Add additional size PNG's for some newly added icons.
  * Add support to the theme for the new cs-input-method icon.
* Sat Oct 17 2015 sor.alexei@meowr.ru
- Initial package.
